@@ -1,19 +1,22 @@
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
  Mixcloud (Music)
-
- @website     https://http://www.mixcloud.com/
- @provide-api yes (http://www.mixcloud.com/developers/
-
- @using-api   yes
- @results     JSON
- @stable      yes
- @parse       url, title, content, embedded, publishedDate
 """
 
 from json import loads
 from dateutil import parser
 from urllib.parse import urlencode
 
+# about
+about = {
+    "website": 'https://www.mixcloud.com/',
+    "wikidata_id": 'Q6883832',
+    "official_api_documentation": 'http://www.mixcloud.com/developers/',
+    "use_official_api": True,
+    "require_api_key": False,
+    "results": 'JSON',
+}
+
 # engine dependent config
 categories = ['music']
 paging = True
