@@ -10,7 +10,7 @@ class AnswererTest(SearxTestCase):
 
     def test_unicode_input(self):
         query = Mock()
-        unicode_payload = u'árvíztűrő tükörfúrógép'
+        unicode_payload = 'árvíztűrő tükörfúrógép'
         for answerer in answerers:
-            query.query = u'{} {}'.format(answerer.keywords[0], unicode_payload)
+            query.query = '{} {}'.format(answerer.keywords[0], unicode_payload)
             self.assertTrue(isinstance(answerer.answer(query), list))
